@@ -26,7 +26,6 @@
 #endif
 
 #include "gdl-i18n.h"
-#include <gdk/gdkx.h>
 
 #include "gdl-tools.h"
 #include "gdl-dock-master.h"
@@ -130,7 +129,7 @@ gdl_dock_master_class_init (GdlDockMasterClass *klass)
 
     g_object_class_install_property (
         g_object_class, PROP_DEFAULT_TITLE,
-        g_param_spec_string ("default_title", _("Default title"),
+        g_param_spec_string ("default-title", _("Default title"),
                              _("Default title for newly created floating docks"),
                              NULL,
                              G_PARAM_READWRITE));
@@ -145,7 +144,7 @@ gdl_dock_master_class_init (GdlDockMasterClass *klass)
                           G_PARAM_READWRITE));
 
     master_signals [LAYOUT_CHANGED] = 
-        g_signal_new ("layout_changed", 
+        g_signal_new ("layout-changed", 
                       G_TYPE_FROM_CLASS (klass),
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (GdlDockMasterClass, layout_changed),
@@ -491,7 +490,7 @@ gdl_dock_master_drag_motion (GdlDockItem *item,
     }
     else {
         GList *l;
-        
+
         /* try to dock the item in all the docks in the ring in turn */
         for (l = master->toplevel_docks; l; l = l->next) {
             dock = GDL_DOCK (l->data);
@@ -506,10 +505,15 @@ gdl_dock_master_drag_motion (GdlDockItem *item,
                 break;
         }
     }
-    
+
+  
     if (!may_dock) {
         GtkRequisition req;
-        
+	/* Special case for GdlDockItems : they must respect the flags */
+	if(GDL_IS_DOCK_ITEM(item)
+	&& GDL_DOCK_ITEM(item)->behavior & GDL_DOCK_ITEM_BEH_NEVER_FLOATING)
+	    return;
+
         dock = NULL;
         my_request.target = GDL_DOCK_OBJECT (
             gdl_dock_object_get_toplevel (request->applicant));
@@ -528,7 +532,15 @@ gdl_dock_master_drag_motion (GdlDockItem *item,
 
         g_value_init (&my_request.extra, GDK_TYPE_RECTANGLE);
         g_value_set_boxed (&my_request.extra, &my_request.rect);
-    };
+    }
+    /* if we want to enforce GDL_DOCK_ITEM_BEH_NEVER_FLOATING		*/
+    /* the item must remain attached to the controller, otherwise	*/
+    /* it could be inserted in another floating dock			*/
+    /* so check for the flag at this moment				*/
+    else if(GDL_IS_DOCK_ITEM(item)
+	&& GDL_DOCK_ITEM(item)->behavior & GDL_DOCK_ITEM_BEH_NEVER_FLOATING
+	&& dock != GDL_DOCK(master->controller))
+	    return;
 
     if (!(my_request.rect.x == request->rect.x &&
           my_request.rect.y == request->rect.y &&
@@ -582,7 +594,7 @@ gdl_dock_master_xor_rect (GdlDockMaster *master)
     }
     
     rect = &master->_priv->drag_request->rect;
-    window = gdk_window_lookup (gdk_x11_get_default_root_xwindow ());
+    window = gdk_get_default_root_window ();
 
     if (!master->_priv->root_xor_gc) {
         GdkGCValues values;
@@ -618,10 +630,10 @@ gdl_dock_master_layout_changed (GdlDockMaster *master)
 {
     g_return_if_fail (GDL_IS_DOCK_MASTER (master));
 
-    /* emit "layout_changed" on the controller to notify the user who
+    /* emit "layout-changed" on the controller to notify the user who
      * normally shouldn't have access to us */
     if (master->controller)
-        g_signal_emit_by_name (master->controller, "layout_changed");
+        g_signal_emit_by_name (master->controller, "layout-changed");
 
     /* remove the idle handler if there is one */
     if (master->_priv->idle_layout_changed_id) {
