@@ -4,20 +4,19 @@
  *
  * Copyright (C) 2002 Gustavo Girldez <gustavo.giraldez@gmx.net>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.  
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -187,7 +186,7 @@ gdl_dock_notebook_instance_init (GdlDockNotebook *notebook)
     item->child = gtk_notebook_new ();
     gtk_widget_set_parent (item->child, GTK_WIDGET (notebook));
     gtk_notebook_set_tab_pos (GTK_NOTEBOOK (item->child), GTK_POS_BOTTOM);
-    g_signal_connect (item->child, "switch_page",
+    g_signal_connect (item->child, "switch-page",
                       (GCallback) gdl_dock_notebook_switch_page_cb, (gpointer) item);
     g_signal_connect (item->child, "notify::page",
                       (GCallback) gdl_dock_notebook_notify_cb, (gpointer) item);
@@ -289,7 +288,7 @@ gdl_dock_notebook_switch_page_cb (GtkNotebook     *nb,
     if (GDL_DOCK_ITEM_USER_ACTION (notebook) &&
         GDL_DOCK_OBJECT (notebook)->master)
         g_signal_emit_by_name (GDL_DOCK_OBJECT (notebook)->master,
-                               "layout_changed");
+                               "layout-changed");
 }
 
 static void
@@ -389,7 +388,7 @@ gdl_dock_notebook_dock (GdlDockObject    *object,
             
             label = gdl_dock_item_get_tablabel (requestor_item);
             if (!label) {
-                g_object_get (requestor_item, "long_name", &name, NULL);
+                g_object_get (requestor_item, "long-name", &name, NULL);
                 label = gtk_label_new (name);
                 g_free (name);
                 gdl_dock_item_set_tablabel (requestor_item, label);
@@ -405,10 +404,17 @@ gdl_dock_notebook_dock (GdlDockObject    *object,
             if (other_data && G_VALUE_HOLDS (other_data, G_TYPE_INT))
                 position = g_value_get_int (other_data);
             
-            gtk_notebook_insert_page (GTK_NOTEBOOK (item->child), 
-                                      GTK_WIDGET (requestor), label,
-                                      position);
+            position = gtk_notebook_insert_page (GTK_NOTEBOOK (item->child), 
+                                                 GTK_WIDGET (requestor), label,
+                                                 position);
             GDL_DOCK_OBJECT_SET_FLAGS (requestor, GDL_DOCK_ATTACHED);
+            
+            /* Set current page to the newly docked widget. set current page
+             * really doesn't work if the page widget is not shown
+             */
+            gtk_widget_show (GTK_WIDGET (requestor));
+            gtk_notebook_set_current_page (GTK_NOTEBOOK (item->child),
+                                           position);
         }
     }
     else
@@ -418,7 +424,7 @@ gdl_dock_notebook_dock (GdlDockObject    *object,
 
 static void
 gdl_dock_notebook_set_orientation (GdlDockItem    *item,
-				   GtkOrientation  orientation)
+                                   GtkOrientation  orientation)
 {
     if (item->child && GTK_IS_NOTEBOOK (item->child)) {
         if (orientation == GTK_ORIENTATION_HORIZONTAL)
